@@ -49,9 +49,6 @@ class ZoomableGraphicView(SelectableGraphicView):
 
         self.zoomed.connect(self.on_signal_zoomed)
 
-        self.scene_y_min = float("nan")  # NaN = AutoDetect
-        self.scene_y_max = float("nan")  # NaN = AutoDetect
-
         self.scene_x_zoom_stretch = 1
 
     @property
@@ -61,7 +58,7 @@ class ZoomableGraphicView(SelectableGraphicView):
                 # Normal scene
                 return 0
             else:
-                return -self.signal.qad_center
+                return -self.signal.center
         except Exception as e:
             logger.error("Could not access y_center property: {0}. Falling back to 0".format(e))
             return 0
@@ -161,8 +158,6 @@ class ZoomableGraphicView(SelectableGraphicView):
     def plot_data(self, data):
         if self.scene_manager is None:
             self.scene_manager = SceneManager(self)
-            self.scene_manager.minimum = self.scene_y_min
-            self.scene_manager.maximum = self.scene_y_max
 
         self.scene_manager.plot_data = data
         self.scene_manager.init_scene()
@@ -181,6 +176,8 @@ class ZoomableGraphicView(SelectableGraphicView):
 
             if self.scene_type == 1:
                 self.scene().redraw_legend()
+            else:
+                self.scene().hide_legend()
 
     def _get_sub_path_ranges_and_colors(self, start: float, end: float):
         # Overwritten in Epic Graphic View
